==> forms-v5.2.1.tar.gz: forms/l10n/hr.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Obrasci",
    "{user} has shared the form {formTitle} with you" : "{user} je s vama podijelio obrazac {formTitle}",
    "{user} has shared the form {formTitle} with group {group}" : "{user} je podijelio obrazac {formTitle} s grupom {group}",
    "Anonymous user" : "Anonimni korisnik",
    "A form has been <strong>shared</strong> with you" : "Obrazac je <strong>podijeljen</strong> s vama",
    "Someone <strong>answered</strong> a form" : "Netko je <strong>odgovorio</strong> na obrazac",
    "No" : "Ne",
    "Yes" : "Da",
    "Copy" : "Kopiraj",
    "Anonymous response" : "Anoniman odgovor",
    "Shared by %s" : "Dijeli %s",
    "responses" : "odgovori",
    "User display name" : "Ime za prikaz korisnika",
    "Timestamp" : "Vremenska oznaka",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Jednostavne ankete i upitnici, samopostavljeni",
    "An error occurred while loading the forms list" : "Došlo je do pogreške pri učitavanju popisa obrazaca",
    "Form not found" : "Obrazac nije pronađen",
    "Unable to create a new form" : "Nije moguće stvoriti novi obrazac",
    "Unable to copy form" : "Kopiranje obrasca nije moguće",
    "New form" : "Novi obrazac",
    "Shared with you" : "Podijeljeno s vama",
    "Loading forms …" : "Učitavanje obrazaca…",
    "No forms created yet" : "Nema stvorenih obrazaca",
    "Create a form" : "Stvori obrazac",
    "Select a form or create a new one" : "Otvori obrazac ili stvori novi",
    "Create new form" : "Stvori novi obrazac",
    "This form does not exist" : "Ovaj obrazac ne postoji",
    "Form expired" : "Obrazac je istekao",
    "This form has expired and is no longer taking answers" : "Ovaj je obrazac istekao i nije moguće unositi odgovore",
    "Select groups" : "Označi grupe",
    "Delete form" : "Izbriši obrazac",
    "Error while deleting {title}" : "Pogreška pri brisanju {title}",
    "Share form" : "Dijeli obrazac",
    "Results" : "Rezultati",
    "Copy form" : "Kopiraj obrazac",
    "Are you sure you want to delete {title}?" : "Jeste li sigurni da želite izbrisati {title}?",
    "Cancel" : "Odustani",
    "Options" : "Mogućnosti",
    "Answer number {index}" : "Broj odgovora {index}",
    "Error while saving the answer" : "Pogreška pri spremanju odgovora",
    "Delete answer" : "Izbriši odgovor",
    "This question needs a title!" : "Potreban je naslov za ovo pitanje!",
    "Question number {index}" : "Broj pitanja {index}",
    "Title of question number {index}" : "Broj naslova pitanja {index}",
    "Required" : "Obvezno",
    "Delete question" : "Izbriši pitanje",
    "Maximum file size" : "Maksimalna veličina datoteke",
    "Delete" : "Izbriši",
    "Uploading …" : "Otpremanje...",
    "A long answer for the question “{text}”" : "Dugi odgovor na pitanje „{text}“",
    "Other" : "Drugo",
    "A short answer for the question “{text}”" : "Kratak odgovor na pitanje „{text}“",
    "No response" : "Nema odgovora",
    "Delete this response" : "Izbriši ovaj odgovor",
    "Expired on {date}" : "Isteklo {date}",
    "Expires on {date}" : "Istječe {date}",
    "never" : "nikad",
    "Allow multiple responses per person" : "Omogući višestruke odgovore po osobi",
    "Set expiration date" : "Postavi datum isteka",
    "Group" : "Grupa",
    "Permissions" : "Dopuštenja",
    "Share link" : "Dijeli poveznicu",
    "Add link" : "Dodaj poveznicu",
    "Copy to clipboard" : "Kopiraj u međuspremnik",
    "Copy embedding code" : "Kopiraj šifru za ugradnju",
    "Internal link" : "Dijeli internu poveznicu",
    "View" : "Pregledaj",
    "Edit" : "Uredi",
    "View mode" : "Način prikaza",
    "Share" : "Dijeli",
    "Responses are anonymous." : "Odgovori su anonimni.",
    "An asterisk (*) indicates mandatory questions." : "Zvjezdica (*) označava obavezna pitanja.",
    "There was an error while adding the new question" : "Došlo je do pogreške pri dodavanju novog pitanja",
    "There was an error while removing the question" : "Došlo je do pogreške pri uklanjanju pitanja",
    "Error while saving form" : "Pogreška pri spremanju obrasca",
    "Loading {title} …" : "Učitavanje {title}…",
    "Form title" : "Naslov obrasca",
    "Description" : "Opis",
    "Add a question" : "Dodaj pitanje",
    "Summary" : "Sažetak",
    "Responses" : "Odgovori",
    "There was an error while loading the results" : "Došlo je do pogreške pri učitavanju rezultata",
    "Export successful to {file}" : "Uspješan izvoz u {file}",
    "There was an error, while exporting to Files" : "Došlo je do pogreške pri izvozu u Files",
    "There was an error while removing this response" : "Došlo je do pogreške pri uklanjanju ovog odgovora",
    "There was an error while removing responses" : "Došlo je do pogreške pri uklanjanju odgovora",
    "{amount} responses" : "{amount} odgovora",
    "Download" : "Preuzmi",
    "Delete all responses" : "Izbriši sve odgovore",
    "Search" : "Traži",
    "Loading responses …" : "Učitavanje odgovora…",
    "No results found" : "Nema rezultata",
    "No responses yet" : "Još nema odgovora",
    "Results of submitted forms will show up here" : "Ovdje će se prikazati rezultati poslanih obrazaca",
    "Are you sure you want to delete all responses of {title}?" : "Jeste li sigurni da želite izbrisati sve odgovore u {title}?",
    "Sharing" : "Dijeljenje",
    "Settings" : "Postavke",
    "Abort" : "Prekid",
    "Submit" : "Šalji",
    "Clear" : "Izbriši",
    "There was an error submitting the form" : "Došlo je do pogreške pri slanju obrasca",
    "Submit form" : "Šalji obrazac",
    "Submitting form …" : "Slanje obrasca u tijeku…",
    "Thank you for completing the form!" : "Hvala što ste ispunili obrazac!",
    "You have unsaved changes! Do you still want to leave?" : "Postoje nespremljene promjene! Želite li još uvijek izaći?",
    "Error while saving question" : "Pogreška pri spremanju pitanja",
    "There was an issue deleting this option" : "Došlo je do problema pri brisanju ove opcije",
    "Form link copied" : "Poveznica na obrazac je kopirana",
    "Cannot copy, please copy the link manually" : "Kopiranje nije moguće, ručno kopirajte poveznicu",
    "No recommendations. Start typing." : "Nema preporuka. Započnite unos.",
    "No elements found." : "Elementi nisu pronađeni.",
    "Checkboxes" : "Potvrdni okviri",
    "Checkbox question title" : "Naslov pitanja s potvrdnim okvirom",
    "This question needs a title and at least one answer!" : "Potrebni su naslov i barem jedan odgovor za ovo pitanje!",
    "Dropdown" : "Padajući izbornik",
    "Dropdown question title" : "Padajući izbornik naslova pitanja",
    "People can pick one option" : "Sudionici mogu odabrati jednu mogućnost",
    "Pick an option" : "Odaberite mogućnost",
    "File" : "Datoteka",
    "Short answer" : "Kratak odgovor",
    "Short answer question title" : "Naslov pitanja s kratkim odgovorom",
    "People can enter a short answer" : "Osobe mogu unijeti kratak odgovor",
    "Long text" : "Dugi tekst",
    "Long text question title" : "Naslov dugog pitanja",
    "People can enter a long text" : "Osobe mogu unijeti dugi tekst",
    "Date" : "Datum",
    "Date question title" : "Datum naslova pitanja",
    "People can pick a date" : "Sudionici mogu odabrati datum",
    "Pick a date" : "Odaberi datum",
    "Datetime" : "Datum i vrijeme",
    "Datetime question title" : "Datum i vrijeme naslova pitanja",
    "People can pick a date and time" : "Sudionici mogu odabrati datum i vrijeme",
    "Pick a date and time" : "Odaberite datum i vrijeme",
    "Time" : "Vrijeme",
    "Pick a time" : "Odaberi vrijeme",
    "Color" : "Boja",
    "Image" : "Slika",
    "Presentation" : "Prezentacija",
    "Text" : "Tekst",
    "Phone number" : "Broj telefona",
    "Email address" : "Adresa e-pošte"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> forms-v5.2.2.tar.gz: forms/l10n/hr.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Obrasci",
    "{user} has shared the form {formTitle} with you" : "{user} je s vama podijelio obrazac {formTitle}",
    "{user} has shared the form {formTitle} with group {group}" : "{user} je podijelio obrazac {formTitle} s grupom {group}",
    "Anonymous user" : "Anonimni korisnik",
    "A form has been <strong>shared</strong> with you" : "Obrazac je <strong>podijeljen</strong> s vama",
    "Someone <strong>answered</strong> a form" : "Netko je <strong>odgovorio</strong> na obrazac",
    "No" : "Ne",
    "Yes" : "Da",
    "Copy" : "Kopiraj",
    "Anonymous response" : "Anoniman odgovor",
    "Shared by %s" : "Dijeli %s",
    "responses" : "odgovori",
    "User display name" : "Ime za prikaz korisnika",
    "Timestamp" : "Vremenska oznaka",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Jednostavne ankete i upitnici, samopostavljeni",
    "An error occurred while loading the forms list" : "Došlo je do pogreške pri učitavanju popisa obrazaca",
    "Form not found" : "Obrazac nije pronađen",
    "Unable to create a new form" : "Nije moguće stvoriti novi obrazac",
    "Unable to copy form" : "Kopiranje obrasca nije moguće",
    "New form" : "Novi obrazac",
    "Shared with you" : "Podijeljeno s vama",
    "No forms created yet" : "Nema stvorenih obrazaca",
    "Create a form" : "Stvori obrazac",
    "Select a form or create a new one" : "Otvori obrazac ili stvori novi",
    "Create new form" : "Stvori novi obrazac",
    "This form does not exist" : "Ovaj obrazac ne postoji",
    "Form expired" : "Obrazac je istekao",
    "This form has expired and is no longer taking answers" : "Ovaj je obrazac istekao i nije moguće unositi odgovore",
    "Select groups" : "Označi grupe",
    "Delete form" : "Izbriši obrazac",
    "Error while deleting {title}" : "Pogreška pri brisanju {title}",
    "Share form" : "Dijeli obrazac",
    "Results" : "Rezultati",
    "Copy form" : "Kopiraj obrazac",
    "Are you sure you want to delete {title}?" : "Jeste li sigurni da želite izbrisati {title}?",
    "Cancel" : "Odustani",
    "Options" : "Mogućnosti",
    "Answer number {index}" : "Broj odgovora {index}",
    "Error while saving the answer" : "Pogreška pri spremanju odgovora",
    "Delete answer" : "Izbriši odgovor",
    "This question needs a title!" : "Potreban je naslov za ovo pitanje!",
    "Question number {index}" : "Broj pitanja {index}",
    "Title of question number {index}" : "Broj naslova pitanja {index}",
    "Required" : "Obvezno",
    "Delete question" : "Izbriši pitanje",
    "Maximum file size" : "Maksimalna veličina datoteke",
    "Delete" : "Izbriši",
    "A long answer for the question “{text}”" : "Dugi odgovor na pitanje „{text}“",
    "Other" : "Drugo",
    "A short answer for the question “{text}”" : "Kratak odgovor na pitanje „{text}“",
    "No response" : "Nema odgovora",
    "Delete this response" : "Izbriši ovaj odgovor",
    "Expired on {date}" : "Isteklo {date}",
    "Expires on {date}" : "Istječe {date}",
    "never" : "nikad",
    "Allow multiple responses per person" : "Omogući višestruke odgovore po osobi",
    "Set expiration date" : "Postavi datum isteka",
    "Group" : "Grupa",
    "Permissions" : "Dopuštenja",
    "Share link" : "Dijeli poveznicu",
    "Add link" : "Dodaj poveznicu",
    "Copy to clipboard" : "Kopiraj u međuspremnik",
    "Copy embedding code" : "Kopiraj šifru za ugradnju",
    "Internal link" : "Dijeli internu poveznicu",
    "View" : "Pregledaj",
    "Edit" : "Uredi",
    "View mode" : "Način prikaza",
    "Share" : "Dijeli",
    "Responses are anonymous." : "Odgovori su anonimni.",
    "An asterisk (*) indicates mandatory questions." : "Zvjezdica (*) označava obavezna pitanja.",
    "There was an error while adding the new question" : "Došlo je do pogreške pri dodavanju novog pitanja",
    "There was an error while removing the question" : "Došlo je do pogreške pri uklanjanju pitanja",
    "Error while saving form" : "Pogreška pri spremanju obrasca",
    "Form title" : "Naslov obrasca",
    "Description" : "Opis",
    "Add a question" : "Dodaj pitanje",
    "Summary" : "Sažetak",
    "Responses" : "Odgovori",
    "There was an error while loading the results" : "Došlo je do pogreške pri učitavanju rezultata",
    "Export successful to {file}" : "Uspješan izvoz u {file}",
    "There was an error, while exporting to Files" : "Došlo je do pogreške pri izvozu u Files",
    "There was an error while removing this response" : "Došlo je do pogreške pri uklanjanju ovog odgovora",
    "There was an error while removing responses" : "Došlo je do pogreške pri uklanjanju odgovora",
    "{amount} responses" : "{amount} odgovora",
    "Download" : "Preuzmi",
    "Delete all responses" : "Izbriši sve odgovore",
    "Search" : "Traži",
    "No results found" : "Nema rezultata",
    "No responses yet" : "Još nema odgovora",
    "Results of submitted forms will show up here" : "Ovdje će se prikazati rezultati poslanih obrazaca",
    "Are you sure you want to delete all responses of {title}?" : "Jeste li sigurni da želite izbrisati sve odgovore u {title}?",
    "Sharing" : "Dijeljenje",
    "Settings" : "Postavke",
    "Abort" : "Prekid",
    "Submit" : "Šalji",
    "Clear" : "Izbriši",
    "There was an error submitting the form" : "Došlo je do pogreške pri slanju obrasca",
    "Submit form" : "Šalji obrazac",
    "Thank you for completing the form!" : "Hvala što ste ispunili obrazac!",
    "You have unsaved changes! Do you still want to leave?" : "Postoje nespremljene promjene! Želite li još uvijek izaći?",
    "Error while saving question" : "Pogreška pri spremanju pitanja",
    "There was an issue deleting this option" : "Došlo je do problema pri brisanju ove opcije",
    "Form link copied" : "Poveznica na obrazac je kopirana",
    "Cannot copy, please copy the link manually" : "Kopiranje nije moguće, ručno kopirajte poveznicu",
    "No recommendations. Start typing." : "Nema preporuka. Započnite unos.",
    "No elements found." : "Elementi nisu pronađeni.",
    "Checkboxes" : "Potvrdni okviri",
    "Checkbox question title" : "Naslov pitanja s potvrdnim okvirom",
    "This question needs a title and at least one answer!" : "Potrebni su naslov i barem jedan odgovor za ovo pitanje!",
    "Dropdown" : "Padajući izbornik",
    "Dropdown question title" : "Padajući izbornik naslova pitanja",
    "People can pick one option" : "Sudionici mogu odabrati jednu mogućnost",
    "Pick an option" : "Odaberite mogućnost",
    "File" : "Datoteka",
    "Short answer" : "Kratak odgovor",
    "Short answer question title" : "Naslov pitanja s kratkim odgovorom",
    "People can enter a short answer" : "Osobe mogu unijeti kratak odgovor",
    "Long text" : "Dugi tekst",
    "Long text question title" : "Naslov dugog pitanja",
    "People can enter a long text" : "Osobe mogu unijeti dugi tekst",
    "Date" : "Datum",
    "Date question title" : "Datum naslova pitanja",
    "People can pick a date" : "Sudionici mogu odabrati datum",
    "Pick a date" : "Odaberi datum",
    "Datetime" : "Datum i vrijeme",
    "Datetime question title" : "Datum i vrijeme naslova pitanja",
    "People can pick a date and time" : "Sudionici mogu odabrati datum i vrijeme",
    "Pick a date and time" : "Odaberite datum i vrijeme",
    "Time" : "Vrijeme",
    "Pick a time" : "Odaberi vrijeme",
    "Color" : "Boja",
    "Image" : "Slika",
    "Presentation" : "Prezentacija",
    "Text" : "Tekst",
    "Phone number" : "Broj telefona",
    "Email address" : "Adresa e-pošte",
    "Loading forms …" : "Učitavanje obrazaca…",
    "Uploading …" : "Otpremanje...",
    "Loading {title} …" : "Učitavanje {title}…",
    "Loading responses …" : "Učitavanje odgovora…",
    "Submitting form …" : "Slanje obrasca u tijeku…"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
